package com.zx.dataservice.controller;

/**
 * Created by qlm on 2020-12-14.
 */

import org.springframework.stereotype.Component;

import javax.websocket.*;
import javax.websocket.server.PathParam;
import javax.websocket.server.ServerEndpoint;
import java.io.IOException;
import java.util.HashMap;
import java.util.Map;
import java.util.Map.Entry;
import java.util.concurrent.ConcurrentHashMap;


@ServerEndpoint("/websocket/{userId}")
@Component
public class WebSocketController {

//    public static Map<String,Session> map = new HashMap<String,Session>();

    private static ConcurrentHashMap<String, Session> map = new ConcurrentHashMap<>();//根据用户找session

    /**
     * 连接建立成功时调用
     * @param userId 登录用户id
     * @param session  可选的参数。session为与某个客户端的连接会话，需要通过它来给客户端发送数据
     * @throws IOException
     */
    @OnOpen
    public void onOpen(Session session, @PathParam("userId") String userId) throws IOException{
        String[] a = userId.split("&");

        String mUserId = a[0];
        map.put(mUserId + "",session);       //添加到链接map
        try{
            System.out.println(mUserId+"连接成功");
            sendUnreadMsg(session);
        }
        catch (Exception e){
            e.printStackTrace();
        }
    }

    /**
     * 连接成功时发送的信息
     */
    public static void sendUnreadMsg(Session session){
            synchronized(session){
                if(session.isOpen()){
                    try {
                        session.getBasicRemote().sendText("连接成功");
                    }catch (Exception e) {
                        e.printStackTrace();
                    }
                }
            }
    }


    /**
     * 连接关闭调用的方法
     */
    @OnClose
    public void onClose(Session session){
        if(map.containsValue(session)){
            for (Entry<String, Session> entry : map.entrySet()){
                if(entry.getValue().equals(session)){
                    map.remove(entry.getKey());
                    break;
                }
            }
        }
    }

    /**
     * 发生错误时调用
     * @param session
     * @param error
     */
    @OnError
    public void onError(Session session, Throwable error){
        if(map.containsValue(session)){
            for (Entry<String, Session> entry : map.entrySet()) {
                if(entry.getValue().equals(session)){
                    map.remove(entry.getKey());
                    break;
                }
            }
        }
        error.printStackTrace();
    }

    public void remWSKey(String key){
        map.remove(key);
    }

    /**
     * 消息发送时调用
     * @param requestJson
     * @param session
     */
    @OnMessage
    public void onMessage(String requestJson, Session session) {

        System.out.println("啦啦啦");

    }


    /**
     */
    public static void sendSysMsg(String id ,String  xMessage){

        try{
            // 数据服务器 id   ：

            Session session = map.get( id);               //发送消息给对方
            if(session!=null){
                synchronized(session){
                    session.getBasicRemote().sendText(xMessage);
                }
            }
        }catch(IOException e) {
            e.printStackTrace();
        }
    }

}